package hw.tagApi.service.service;

import java.util.List;
import java.util.Set;

import hw.tagApi.service.domain.HwTagRecord;
import hw.tagApi.service.domain.ImportParams;
import hw.tagApi.service.domain.ImportResult;

/**
 * 标签记录Service接口
 * 
 * @author Yinq
 * @date 2025-04-15
 */
public interface IHwTagRecordService 
{
    /**
     * 查询标签记录
     * 
     * @param rId 标签记录主键
     * @return 标签记录
     */
    public HwTagRecord selectHwTagRecordByRId(Long rId);

    /**
     * 查询标签记录列表
     * 
     * @param hwTagRecord 标签记录
     * @return 标签记录集合
     */
    public List<HwTagRecord> selectHwTagRecordList(HwTagRecord hwTagRecord);

    /**
     * 新增标签记录
     * 
     * @param hwTagRecord 标签记录
     * @return 结果
     */
    public int insertHwTagRecord(HwTagRecord hwTagRecord);

    /**
     * 修改标签记录
     * 
     * @param hwTagRecord 标签记录
     * @return 结果
     */
    public int updateHwTagRecord(HwTagRecord hwTagRecord);

    /**
     * 批量删除标签记录
     * 
     * @param rIds 需要删除的标签记录主键集合
     * @return 结果
     */
    public int deleteHwTagRecordByRIds(Long[] rIds);

    /**
     * 删除标签记录信息
     * 
     * @param rId 标签记录主键
     * @return 结果
     */
    public int deleteHwTagRecordByRId(Long rId);

    /**
     * 根据TID更新标签记录
     *
     * @param record 标签记录
     */
    public void updateHwTagRecordByTID(HwTagRecord record);

    /**
     * 批量插入标签记录
     *
     * @param batchList 标签记录列表
     */
    public void batchInsertHwTagRecord(List<HwTagRecord> batchList);


    /**
     * 查询接口根据条件查询标签记录
     *
     * @param selectTagRecord （HwTagRecord）
     * @return HwTagRecord
     */
    public HwTagRecord selectHwTagRecordData(HwTagRecord selectTagRecord);

    /**
     * 根据TID查询标签记录
     *
     * @param tId TID
     */
    public HwTagRecord selectHwTagRecordByTID(String tId);

    /**
     * 批量查询已存在的TID
     *
     * @param tids TID列表
     * @return 已存在的TID集合
     */
    public Set<String> selectExistingTids(List<String> tids);

    /**
     * 批量查询已存在的EPC
     *
     * @param epcs EPC列表
     * @return 已存在的EPC集合
     */
    public List<HwTagRecord> selectExistingEpcs(List<String> epcs);

    /**
     * 处理标签列表
     */
    public ImportResult processTagList(List<HwTagRecord> records, ImportParams params);
}
